<?php
namespace EasyVideoReviews;

defined('ABSPATH') or die('NOT ALLOWED');

# Handles admin ajax
if (!class_exists('\EasyVideoReviews\AdminAjax')) {
    
    final class AdminAjax 
    {  
        
        public $instanced = null;
        
        # Singleton pattern to avoid multiple instance of this class
        public function __construct()
        {
            if($this->instanced !== true) {
                $this->instanced = true;
                $this->register_hooks();
            }
        }

        # Register hooks
        function register_hooks()
        {

            add_action('wp_ajax_evr_save_token', [$this, 'save_auth_token']);
            add_action('wp_ajax_evr_save_accessibility', [$this, 'evr_save_accessibility']);
            add_action('wp_ajax_evr_logout', [$this, 'evr_logout']);
            add_action('wp_ajax_get_evr_settings', [$this, 'get_evr_settings']);
            add_action('wp_ajax_update_evr_settings', [$this, 'update_evr_settings']);

            add_action('wp_ajax_import_evr_settings', [$this, 'import_evr_settings']);
            add_action('wp_ajax_reset_evr_settings', [$this, 'reset_evr_settings']);

            add_action('wp_ajax_update_notice_variable', [$this, 'update_evr_notice_variable']); 

            // load file content and return as blob 
            add_action('wp_ajax_evr_load_file_content', [$this, 'ajax_load_file_content']);
        } 

        # Save auth token for next authentication
        function save_auth_token()
        {
            $inputs = App::inputs(); # sanitized inputs

            $token =  $inputs->token; 
            if(!empty($token)) {
                update_option('evr_token', $token); 
            }

            evr_log('Token saved' . $token);
            wp_send_json_success();
            wp_die();
        }


        # updates accessibility remotely
        function evr_save_accessibility()
        {
            $inputs = App::inputs(); # sanitized inputs

            update_option('evr_isPro', $inputs->is_pro); 
            wp_send_json_success($inputs->is_pro);
            wp_die();
        }

        # Logout and delete auth token
        function evr_logout()
        { 
            delete_option('evr_token', true);
            delete_option('evr_isPro', true);
            evr_log('Logged out');
            wp_send_json_success();
            wp_die();
        }
 

        /**
         * Get EVR settings
         */
        function get_evr_settings()
        {
            $options = App::get_options();

            $output = [];

            foreach ($options as $key => $value) {
                $output[$key] = get_evr_option($key);
            }

            wp_send_json($output);
        }

        /**
         * Update EVR Plugin Options
         */
        function update_evr_settings()
        { 

            $inputs = App::inputs(); # sanitized inputs

            $options = App::get_options();
            $v = [];
            foreach ($options as $key => $default) {
                $updated_value = $inputs->$key; 
                update_option('evr_' . $key, $updated_value);
                $v[] = $updated_value;
            }

            evr_log('Updated settings');
            wp_send_json_success($inputs);
        }

        /**
         * Import EVR Plugin Options
         */

        function import_evr_settings()
        {

            $inputs = (array) App::inputs(); # sanitized inputs

            $options = array_keys(App::get_options());
 
            $inp_options = (array) $inputs['options']; 
            foreach ($inp_options as $key => $value) {
                if (in_array($key, $options)) { 
                    $updated_value = $inp_options[$key];  
                    update_option('evr_' . $key, $updated_value);
                }
            }

            evr_log ('Imported settings');
            wp_send_json_success();
            wp_die();
        }

        /**
         * Export EVR Plugin Options
         */
        function export_evr_settings()
        {

            $options = array_keys(App::get_options());

            $results = [];
            foreach ($options as $key) {
                $results[$key] = get_evr_option($key);
            }

            if ($results && !empty($results)) wp_send_json_success($results);

            evr_log('Exported settings');
            wp_send_json_error();
            wp_die();
        }

        /**
         * Reset EVR Plugin Options
         */
        function reset_evr_settings()
        {
            $adminHooks = new AdminHooks();
            $response = $adminHooks->reset_evr_options(true);
            evr_log('Reset settings');
            wp_send_json_success();
            wp_die();
        }

        public function update_evr_notice_variable()
        {

            $inputs = App::inputs(); # sanitized inputs

            $notice_variable = $inputs->notice_variable;
            
            if(empty($notice_variable)){
                wp_send_json_error();
                wp_die();
            }

            update_option( $notice_variable, 1);

            evr_log('Updated notices');
            wp_send_json_success( $notice_variable );
            wp_die();
        }

        public function ajax_load_file_content()
        {
            $file = $_REQUEST['file']; 
            $search = $_REQUEST['search']; 
  
            // download file return blob 
            if(!empty($file)){
                $file_content = file_get_contents( $file );
                wp_send_json_success($file_content);
                wp_die();
            }

            wp_send_json_error( [$file, $search]);
            wp_die();
        }
 
    }

    # Execute if only AJAX performed
    if(wp_doing_ajax() === true){
        new AdminAjax();
    }

}
