<?php
namespace EasyVideoReviews;

defined('ABSPATH') or die('NOT ALLOWED');

# EVR Update Adjustment Handler
if (!class_exists("\EasyVideoReviews\Adjustment")) {

    final class Adjustment
    {  
        # Checks saved and current version to adjust updates
        static public function init()
        {
            $instance = new self;
            $savedVersion = get_evr_version(); 
            if(version_compare($savedVersion, EVR_VERSION, '<') || !$savedVersion) $instance->run_updater();
        }

        # Run the updater and save current version 
        public function run_updater()
        { 
            $version = get_evr_version(); 
            $version = $this->get_next_version($version); 
            
            # perform the updater from current installed version to new upgraded version
            while(version_compare($version, EVR_VERSION, '<=')){
                 
                $explodedVersionNumber = explode('.', $version);
                $numericVersion = $explodedVersionNumber[0] . $explodedVersionNumber[1] . $explodedVersionNumber[2];
                $methodName = 'update_' . $numericVersion; 

                if(method_exists( $this, $methodName)){
                    call_user_func([$this, $methodName]);
                }

                $version = $this->get_next_version($version);
            }

            $this->save_current_version();
        }

        # Saves current version
        public function save_current_version()
        {
            update_option('evr_version', EVR_VERSION);
        }

        # Get next version 
        public function get_next_version($versionNumber, $add = 1)
        { 
            $numerosumado = explode( ".", $versionNumber );
            $numerosumado[2] += $add;
            if ( $numerosumado[2] > 9 ) { # if last incremented number is greater than 9 reset to 0
                $numerosumado[2] = 0;
                if ( ++$numerosumado[1] > 9 ) { # if second incremented number is greater than 9 reset to 0
                    $numerosumado[1] = 0;
                    ++$numerosumado[0]; # incremented first number
                }
            }
            $numerosumado = implode( ".", $numerosumado );
            return $numerosumado;
        }

        # Update for specific versions as an adjustment
        public function update_117()
        { 
            $translations =  App::get_translations();
            update_option('evr_translations', $translations);
            evr_log ('Updated translations');
        }
    }

    add_action('plugins_loaded', ['\EasyVideoReviews\Adjustment', 'init']); 
}