<?php

namespace EasyVideoReviews;

defined('ABSPATH') or die('NOT ALLOWED');


# The core app of Easy Video Reviews 

if (!class_exists('\EasyVideoReviews\App')) {

    final class App
    {
        static public function instance()
        {
            return new self;
        }

        # get sanitized inputs from body
        static function inputs()
        {
            try {
                $json = file_get_contents('php://input');
                $request = json_decode(sanitize_text_field($json));
            } catch (\Exception $e) {
            }

            if (!$request || empty($request)) {
                $request =  $_REQUEST;
            }

            #
            $request = self::instance()->sanitize_inputs($request);

            return (object) $request;
        }

        # get inputs from body
        function sanitize_inputs($array_or_string)
        {
            if (is_string($array_or_string)) {
                $array_or_string = sanitize_text_field($array_or_string);
            } elseif (is_array($array_or_string)) {
                foreach ($array_or_string as $key => &$value) {
                    if (is_array($value)) {
                        $value = $this->sanitize_inputs($value);
                    } else {
                        $value = sanitize_text_field($value);
                    }
                }
            }

            return $array_or_string;
        }

        # Get translation labels
        public static function get_translations()
        {
            $texts = [
                'Start',
                'Upload review',
                'Record review',
                'You have no camera installed on your device or the device is currently being used by another application',
                'Please try visiting this page with a valid SSL certificate',
                "You can record up to %s minutes, don't worry you will review your video before sending",
                'Hide options',
                'Show options',
                'Delay',
                'No delay',
                'Seconds',
                'Choose camera',
                'Default camera',
                'Choose microphone',
                'Default microphone',
                'Save options',
                'Looks good, continue',
                'Upload video',
                "You can record up to %s minutes, don't worry you will review your video before sending",
                'Record',
                'Upload',
                'Uploading video...',
                'Record new video',
                "I'm allowing to publish this video",
                'Submit',
                'Record',
                'Start over',
                'Upload video',
                'Drag your files here or click in this area',
                'Continue',
                'Record video',
                'Uploaded Succesfully!',
                'Video Duration Limit Exceeded, Select other file',
                'Please select a file less than %s',
                'Error attempting to enable full-screen mode: %s',
            ];

            $newArray = [];
            foreach ($texts as $text) {
                $newArray[$text] = $text;
            }

            return apply_filters('evr_translations', $newArray);
        }


        /**
         * Get EVR Registered Options 
         */

        public static function get_options()
        {
            $options = [
                'recorder' => [
                    'limits' => 120,
                    'upload' => 0,
                    'publish_policy' => 0,
                    'show_options' => 0,
                    'form' => 0,
                    'enableDelay' => true,
                    'delay' => 3,
                    'auto_approve' => true
                ],
                'recorder_page' => '',
                'email' => [
                    'message' => esc_html__('If you like the product, please leave a video review for us {button}', 'easy-video-reviews'),
                    'button' => [
                        'text' => esc_html__('Leave a video review', 'easy-video-reviews'),
                        'bg' => '#96588a',
                        'color' => '#ffffff',
                        'size' => '16',
                    ],
                    'url' => [
                        'label' => esc_html__('Leave a video review', 'easy-video-reviews')
                    ]
                ],
                'button' => [
                    'text' => esc_html__('Leave a video review', 'easy-video-reviews'),
                    'color' => '#f0f0f0',
                    'bg' => '#000099',
                    'size' => '18',
                    'alignment' => 'center'
                ],
                'optimization' => [
                    'showcase' =>  [
                        'title' => esc_html__('Video Review', 'easy-video-reviews'),
                        'description' => esc_html(get_bloginfo('description')),
                        'slug' => 'video-review',
                    ],
                    'social' => [
                        'facebook' => ['show' => false, 'id' => ''],
                        'twitter' => ['show' => false, 'username' => ''],
                    ]
                ],
                'forms' => [],
                'translations' => self::get_translations()
            ];

            return apply_filters('evr_options', $options);
        }

        /**
         * Client's IP address to log
         */

        public static function get_user_ip()
        {
            $ipaddress = '';
            if (isset($_SERVER['HTTP_CLIENT_IP']))
                $ipaddress = $_SERVER['HTTP_CLIENT_IP'];
            else if (isset($_SERVER['HTTP_X_FORWARDED_FOR']))
                $ipaddress = $_SERVER['HTTP_X_FORWARDED_FOR'];
            else if (isset($_SERVER['HTTP_X_FORWARDED']))
                $ipaddress = $_SERVER['HTTP_X_FORWARDED'];
            else if (isset($_SERVER['HTTP_X_CLUSTER_CLIENT_IP']))
                $ipaddress = $_SERVER['HTTP_X_CLUSTER_CLIENT_IP'];
            else if (isset($_SERVER['HTTP_FORWARDED_FOR']))
                $ipaddress = $_SERVER['HTTP_FORWARDED_FOR'];
            else if (isset($_SERVER['HTTP_FORWARDED']))
                $ipaddress = $_SERVER['HTTP_FORWARDED'];
            else if (isset($_SERVER['REMOTE_ADDR']))
                $ipaddress = $_SERVER['REMOTE_ADDR'];
            else
                $ipaddress = 'UNKNOWN';
            return $ipaddress;
        }


        /**
         * Default Showcase Configuration
         */
        public static function get_showcase_config()
        {
            $configs = [
                "id" => "",
                "tag" => "general",
                "view" => "grid",
                "limit" => 9,
                "order" => "DESC",
                "smcolumns" => 1,
                "mdcolumns" => 2,
                "lgcolumns" => 3,
                "smgap" => 2,
                "mdgap" => 4,
                "lggap" => 6,
                "pagination" => 0,
                "navigation" => 1,
                "scrollbar" => 0,
                "infinity" => 1,
                "autoplay" => 1,
                "delay" => 5000,
                "rounded" => true,
                "date" => false,
            ];

            return apply_filters("evr_showcase_default_config", $configs);
        }


        /**
         * Get remote url 
         */

        public static function get_remote_url()
        {
            return apply_filters("evr_remote_url", 'https://evr.wppool.dev/');
        }


        /**
         * Get debug flag
         */

        public static function debug()
        {
            return apply_filters('evr_debug', false);
        }
    }
}
