<?php

namespace EasyVideoReviews;

if (!defined('ABSPATH')) exit; // Exit if accessed directly


/**
 * Elementor Widget Class for Showcase
 */

if (!class_exists('\EasyVideoReviews\EVR_ElementorShowcase')) {

    class EVR_ElementorShowcase extends \Elementor\Widget_Base
    {

        public function get_name()
        {
            return 'evr-showcase';
        }

        public function get_title()
        {
            return __('Easy Video Reviews Showcase', 'easy-video-reviews');
        }

        public function get_icon()
        {
            return 'evr-logo-icon';
        }

        public function get_categories()
        {
            return ['general'];
        }

        protected function _register_controls()
        {

            $this->start_controls_section(
                'section_content',
                [
                    'label' => __('Showcase', 'easy-video-reviews'),
                ]
            );

            // content 
            // $this->add_control(
            //     'source',
            //     [
            //         'label' => __('Source', 'easy-video-reviews'),
            //         'type' => 'select',
            //         'options' => [
            //             'tag' =>  __('Tag', 'easy-video-reviews'),
            //             'id' => __('ID', 'easy-video-reviews'),
            //         ],
            //         'default' => 'tag',
            //     ]
            // );


            // // source tag 
            // $this->add_control(
            //     'tag',
            //     [
            //         'label' => __('Video Tag', 'easy-video-reviews'),
            //         'type' => 'text',
            //         'default' => "general", 
            //         'condition' => ['source' => 'tag']
            //     ]
            // );

            // // source id 
            // $this->add_control(
            //     'id',
            //     [
            //         'label' => __('Video ID(s)', 'easy-video-reviews'),
            //         'type' => 'text',
            //         'default' => "", 
            //         'condition' => ['source' => 'id']
            //     ]
            // );

            // limit 


            // showcase 
            $this->add_control(
                'view',
                [
                    'label' => __('Showcase View', 'easy-video-reviews'),
                    'type' => 'choose',
                    'options' => [
                        'grid' => [
                            'title' => __('Grid View', 'easy-video-reviews'),
                            'icon' => 'dashicons dashicons-editor-table',
                        ],
                        'slider' => [
                            'title' => __('Carousel View', 'easy-video-reviews'),
                            'icon' => 'dashicons dashicons-slides',
                        ],
                    ],
                    'default' => 'grid',
                ]
            );

            $this->add_control(
                'limit',
                [
                    'label' => __('Video Limit', 'easy-video-reviews'),
                    'type' => 'number',
                    'default' => 10,
                    'min' => 1,
                    'max' => 99,
                ]
            );


            // order 
            $this->add_control(
                'order',
                [
                    'label' => __('Order', 'easy-video-reviews'),
                    'type' => 'select',
                    'options' => [
                        'asc' => __('ASC', 'easy-video-reviews'),
                        'desc' => __('DESC', 'easy-video-reviews'),
                    ],
                    'default' => 'desc',
                ]
            );

            // columns 
            $this->add_responsive_control(
                'column',
                [
                    'label' => __('Columns', 'easy-video-reviews'),
                    'type' => 'number',
                    'min' => 1,
                    'max' => 12,
                    'desktop_default' => 4,
                    'tablet_default' => 3,
                    'mobile_default' => 2,
                ]
            );


            // space between 
            $this->add_responsive_control(
                'gap',
                [
                    'label' => __('Space Between', 'easy-video-reviews'),
                    'type' => 'number',
                    'min' => 1,
                    'max' => 12,
                    'desktop_default' => 3,
                    'tablet_default' => 2,
                    'mobile_default' => 1,
                ]
            );

            $this->add_control(
                'rounded',
                [
                    'label' => __('Rounded Corners', 'easy-video-reviews'),
                    'type' => 'switcher',
                    'default' => true,
                ]
            );

            $this->add_control(
                'date',
                [
                    'label' => __('Show Date', 'easy-video-reviews'),
                    'type' => 'switcher',
                    'default' => false,
                ]
            );


            $this->end_controls_section();

            $this->start_controls_section(
                'carousel_section',
                [
                    'label' => __('Carousel', 'easy-video-reviews'),
                    'condition' => ['view' => 'slider']
                ]
            );


            $this->add_control(
                'autoplay',
                [
                    'label' => __('Enable Autoplay', 'easy-video-reviews'),
                    'type' => 'switcher',
                    'default' => true,
                ]
            );

            $this->add_control(
                'delay',
                [
                    'label' => __('Autoplay Delay', 'easy-video-reviews'),
                    'type' => 'number',
                    'default' => 4000,
                    'min' => 0,
                    'condition' => ['autoplay' => 'yes']
                ]
            );

            $this->add_control(
                'pagination',
                [
                    'label' => __('Enable Pagination', 'easy-video-reviews'),
                    'type' => 'switcher',
                    'default' => false,
                ]
            );

            $this->add_control(
                'navigation',
                [
                    'label' => __('Enable Navigation', 'easy-video-reviews'),
                    'type' => 'switcher',
                    'default' => false,
                ]
            );

            $this->add_control(
                'scrollbar',
                [
                    'label' => __('Enable Scrollbar', 'easy-video-reviews'),
                    'type' => 'switcher',
                    'default' => false,
                ]
            );

            $this->end_controls_section();

            $this->start_controls_section(
                'info_section',
                [
                    'label' => __('Recorder Button', 'easy-video-reviews'),
                ]
            );


            $this->add_control(
                'button',
                [
                    'label' => __('Add Recorder Button', 'easy-video-reviews'),
                    'type' => 'switcher',
                    'default' => false,
                ]
            );

            $this->add_control(
                'button_position',
                [
                    'label' => __('Position', 'easy-video-reviews'),
                    'type' => 'select',
                    'options' => [
                        'top' => __('Top', 'easy-video-reviews'),
                        'bottom' => __('Bottom', 'easy-video-reviews'),
                    ],
                    'default' => 'top',
                    'condition' => ['button' => 'yes']
                ]
            );

            $this->add_control(
                'button_label',
                [
                    'label' => __('Button Label', 'easy-video-reviews'),
                    'type' => 'text',
                    'default' => 'Leave Your Speach!',
                    'condition' => ['button' => 'yes']
                ]
            );

            $this->add_control(
                'button_bg_color',
                [
                    'label' => __('Button Background Color', 'easy-video-reviews'),
                    'type' => 'color',
                    'default' => 'blue', 'condition' => ['button' => 'yes']
                ]
            );
            $this->add_control(
                'button_text_color',
                [
                    'label' => __('Button Text Color', 'easy-video-reviews'),
                    'type' => 'color',
                    'default' => 'white', 'condition' => ['button' => 'yes']
                ]
            );


            $this->add_control(
                'button_size',
                [
                    'label' => __('Size', 'plugin-name'),
                    'type' => 'slider',
                    'size_units' => ['px'],
                    'range' => [
                        'min' => 1,
                        'max' => 72,
                    ],
                    'default' => [
                        'unit' => 'px',
                        'size' => 20,
                    ],
                ]
            );

            $this->add_control(
                'button_alignment',
                [
                    'label' => __('Button Alignment', 'easy-video-reviews'),
                    'type' => 'choose',
                    'options' => [
                        'left' => [
                            'title' => __('Left', 'easy-video-reviews'),
                            'icon' => 'dashicons dashicons-editor-alignleft',
                        ],
                        'center' => [
                            'title' => __('Center', 'easy-video-reviews'),
                            'icon' => 'dashicons dashicons-editor-aligncenter',
                        ],
                        'right' => [
                            'title' => __('Right', 'easy-video-reviews'),
                            'icon' => 'dashicons dashicons-editor-alignright',
                        ],
                    ],
                    'default' => 'center',
                    'condition' => ['button' => 'yes']
                ]
            );

            $this->end_controls_section();
        }

        # render admin button

        protected function render_button_admin($settings)
        {
            $button = '[evr-button align=' . esc_attr($settings['button_alignment']) . ' size=' . esc_attr($settings['button_size']["size"]) . ' color=' . esc_html($settings['button_text_color']) . ' bg=' . esc_html($settings['button_bg_color']) . ' tag=' . esc_attr('general') . ']' . esc_html($settings['button_label']) . '[/evr-button]';
            echo wp_kses_post(do_shortcode($button));
        }

        # admin grid render 
        protected function render_grid_admin($settings)
        {
            // var_dump($settings);
?>
            <div class="evr-reviews relative grid grid-cols-<?php echo esc_html($settings['column_mobile']); ?> md:grid-cols-<?php echo esc_html($settings['column']); ?> sm:grid-cols-<?php echo esc_html($settings['column_tablet']); ?> gap-<?php echo esc_html($settings['gap_mobile']); ?> md:gap-<?php echo esc_html($settings['gap']); ?> sm:gap-<?php echo esc_html($settings['gap_tablet']); ?> md:gap-<?php echo esc_html($settings['gap_tablet']); ?> lg:gap-<?php echo esc_html($settings['gap']); ?>">

                <?php for ($i = 0; $i < $settings['limit']; $i++) :
                    $image_id = abs(($i % 3) + 1); ?>
                    <!-- single  -->
                    <div class="swiper-slide evr-review">
                        <div class="bg-gray-50 overflow-hidden flex flex-col items-center justify-center h-full <?php echo $settings['rounded'] ? 'rounded-md' : ''; ?>">
                            <div class="relative ">
                                <div class="z-50 w-full h-full cursor-pointer rounded-sm">
                                    <video class="z-50 h-full w-full cursor-pointer rounded-sm" poster="<?php echo esc_url(EVR_PUBLIC); ?>/images/person/<?php echo esc_html($image_id); ?>.jpg" src=""></video>
                                </div>
                                <div class="absolute top-0 left-0 w-full h-full flex items-center justify-center z-50 evr-review-overlay">
                                    <a data-play="" class="evr-review-play cursor-pointer opacity-50 hover:opacity-70 transition duration-150 text-white" style="color: white">
                                        <svg xmlns="http://www.w3.org/2000/svg" class="fill-current h-20 w-20" viewBox="0 0 16 16">
                                            <path d="m11.596 8.697-6.363 3.692c-.54.313-1.233-.066-1.233-.697V4.308c0-.63.692-1.01 1.233-.696l6.363 3.692a.802.802 0 0 1 0 1.393z"></path>
                                        </svg>
                                    </a>
                                    <a style="display:none" data-stop="" class="evr-review-stop cursor-pointer opacity-50 hover:opacity-70 transition duration-150 text-white">
                                        <svg xmlns="http://www.w3.org/2000/svg" class="fill-current h-20 w-20" viewBox="0 0 16 16">
                                            <path d="M5.5 3.5A1.5 1.5 0 0 1 7 5v6a1.5 1.5 0 0 1-3 0V5a1.5 1.5 0 0 1 1.5-1.5zm5 0A1.5 1.5 0 0 1 12 5v6a1.5 1.5 0 0 1-3 0V5a1.5 1.5 0 0 1 1.5-1.5z"></path>
                                        </svg>
                                    </a>
                                </div>
                            </div>

                            <?php if ($settings['date']) : ?>
                                <div class="w-full bg-gray-100 py-3 px-4 text-gray-400 text-sm flex items-center justify-between">
                                    <span>3 days ago</span>
                                    <div class="relative">
                                        <div></div>
                                    </div>
                                </div>
                            <?php endif; ?>

                        </div>
                    </div>
                <?php endfor; ?>

                <!-- single ends  -->
            </div>
        <?php
        }
        protected function render_slider_admin($settings)
        {

        ?>
            <div class="evr-reviews evr-reviews-swiper relative grid grid-cols-<?php echo esc_html($settings['column_mobile']); ?> md:grid-cols-<?php echo esc_html($settings['column']); ?> sm:grid-cols-<?php echo esc_html($settings['column_tablet']); ?> gap-<?php echo esc_html($settings['gap_mobile']); ?> md:gap-<?php echo esc_html($settings['gap']); ?> sm:gap-<?php echo esc_html($settings['gap_tablet']); ?> md:gap-<?php echo esc_html($settings['gap_tablet']); ?> lg:gap-<?php echo esc_html($settings['gap']); ?>">
                <div class="swiper-container">

                    <!-- Additional required wrapper -->
                    <div class="swiper-wrapper">

                        <?php for ($i = 0; $i < $settings['limit']; $i++) :
                            $image_id = abs(($i % 3) + 1); ?>
                            <!-- single  -->
                            <div class="swiper-slide evr-review">
                                <div class="bg-gray-50 overflow-hidden flex flex-col items-center justify-center h-full <?php echo $settings['rounded'] ? 'rounded-md' : ''; ?>">
                                    <div class="relative ">
                                        <div class="z-50 w-full h-full cursor-pointer rounded-sm">
                                            <video class="z-50 h-full w-full cursor-pointer rounded-sm" poster="<?php echo esc_url(EVR_PUBLIC); ?>/images/person/<?php echo esc_html($image_id); ?>.jpg" src=""></video>
                                        </div>
                                        <div class="absolute top-0 left-0 w-full h-full flex items-center justify-center z-50 evr-review-overlay">
                                            <a data-play="" class="evr-review-play cursor-pointer opacity-50 hover:opacity-70 transition duration-150 text-white" style="color: white">
                                                <svg xmlns="http://www.w3.org/2000/svg" class="fill-current h-20 w-20" viewBox="0 0 16 16">
                                                    <path d="m11.596 8.697-6.363 3.692c-.54.313-1.233-.066-1.233-.697V4.308c0-.63.692-1.01 1.233-.696l6.363 3.692a.802.802 0 0 1 0 1.393z"></path>
                                                </svg>
                                            </a>
                                            <a style="display:none" data-stop="" class="evr-review-stop cursor-pointer opacity-50 hover:opacity-70 transition duration-150 text-white">
                                                <svg xmlns="http://www.w3.org/2000/svg" class="fill-current h-20 w-20" viewBox="0 0 16 16">
                                                    <path d="M5.5 3.5A1.5 1.5 0 0 1 7 5v6a1.5 1.5 0 0 1-3 0V5a1.5 1.5 0 0 1 1.5-1.5zm5 0A1.5 1.5 0 0 1 12 5v6a1.5 1.5 0 0 1-3 0V5a1.5 1.5 0 0 1 1.5-1.5z"></path>
                                                </svg>
                                            </a>
                                        </div>
                                    </div>

                                    <?php if ($settings['date']) : ?>
                                        <div class="w-full bg-gray-100 py-3 px-4 text-gray-400 text-sm flex items-center justify-between">
                                            <span>3 days ago</span>
                                            <div class="relative">
                                                <div></div>
                                            </div>
                                        </div>
                                    <?php endif; ?>

                                </div>
                            </div>
                        <?php endfor; ?>

                    </div>

                    <!-- If we need pagination -->
                    <div class="swiper-pagination"></div>

                    <!-- If we need navigation buttons -->
                    <div class="swiper-button-prev"></div>
                    <div class="swiper-button-next"></div>

                    <!-- If we need scrollbar -->
                    <div class="swiper-scrollbar"></div>

                </div>
            </div>

            <script>
                (function() {
                    let swiperConfig = {
                        // autoHeight: true,
                        // centeredSlides: true,
                        navigation: true ? {
                            nextEl: ".swiper-button-next",
                            prevEl: ".swiper-button-prev",
                        } : false,
                        observeParents: true,
                        parallax: true,
                        slidesPerView: '<?php echo $settings['column']; ?>',
                        loop: true,
                        autoplay: true,
                        simulateTouch: true,
                        spaceBetween: Math.ceil(<?php echo $settings['gap']; ?>),
                        pagination: true ? {
                            el: ".swiper-pagination",
                            clickable: true,
                        } : false,
                        autoplay: true ? {
                            delay: 1000,
                            disableOnInteraction: false,
                        } : false,
                        speed: 1000,
                        freeMode: true,
                        keyboardControl: true,
                        // preventClicks: true,
                        // preventClicksPropagation: true,
                        scrollbar: true ? true : false,
                        keyboard: {
                            enabled: true,
                            onlyInViewport: false,
                        },
                        breakpoints: {
                            // when window width is >= 320px
                            0: {
                                slidesPerView: <?php echo $settings['column_mobile']; ?>,
                                spaceBetween: <?php echo $settings['gap_mobile']; ?>,
                            },
                            120: {
                                slidesPerView: <?php echo $settings['column_tablet']; ?>,
                                spaceBetween: Math.ceil(<?php echo $settings['gap_tablet']; ?> * 5),
                            },
                            640: {
                                slidesPerView: <?php echo $settings['column']; ?>,
                                spaceBetween: Math.ceil(<?php echo $settings['gap']; ?>* 5),
                            },
                            992: {
                                slidesPerView: <?php echo $settings['column']; ?>,
                                spaceBetween: Math.ceil(<?php echo $settings['gap']; ?>* 5),
                            },
                        },
                    };

                    console.log(swiperConfig);
                    setTimeout(function() {
                        new Swiper(document.querySelector('.evr-reviews-swiper'), swiperConfig);
                    }, 1000)
                })()
            </script>
<?php
        }


        # render_admin 
        protected function render_admin($settings)
        {
            $settings = $this->get_settings_for_display();

            if ($settings['button']) {
                if ($settings['button_position'] == 'top') {
                    $this->render_button_admin($settings);
                }
            }



            switch ($settings['view']) {

                case 'slider':
                    $this->render_slider_admin($settings);
                    break;
                case 'grid':
                default:
                    $this->render_grid_admin($settings);
                    break;
            }


            if ($settings['button']) {
                if ($settings['button_position'] == 'bottom') {
                    $this->render_button_admin($settings);
                }
            }
        }


        protected function render_frontend($settings)
        {

            $showcaseAttrs = [
                'view' => esc_attr($settings['view']),
                'lgcolumns' => esc_attr($settings['column']),
                'mdcolumns' => esc_attr($settings['column_tablet']),
                'smcolumns' => esc_attr($settings['column_mobile']),
                'lggap' => esc_attr($settings['gap']),
                'mdgap' => esc_attr($settings['gap_tablet']),
                'smgap' => esc_attr($settings['gap_mobile']),
                'tag' => esc_attr('general'),
                'limit' => esc_attr($settings['limit']),
                'order' => esc_attr($settings['order']),
                'autoplay' => esc_attr($settings['autoplay'] == 'yes'),
                'delay' => esc_attr($settings['delay']),
                'pagination' => esc_attr($settings['pagination'] == 'yes'),
                'navigation' => esc_attr($settings['navigation'] == 'yes'),
                'scrollbar' => esc_attr($settings['scrollbar'] == 'yes'),
                'date' => esc_attr($settings['date'] == 'yes'),
                'rounded' => esc_attr($settings['rounded'] == 'yes'),
            ];


            $renderedShowcaseAttrs = "";

            foreach ($showcaseAttrs as $key => $value) {
                $renderedShowcaseAttrs .= " {$key}=\"{$value}\"";
            }

            $showcase = "[evr-videos {$renderedShowcaseAttrs}][/evr-videos]";

            $button = '[evr-button align=' . esc_attr($settings['button_alignment']) . ' size=' . esc_attr($settings['button_size']["size"]) . ' color=' . esc_html($settings['button_text_color']) . ' bg=' . esc_html($settings['button_bg_color']) . ' tag=' . esc_attr('general') . ']' . esc_html($settings['button_label']) . '[/evr-button]';

            $output = $showcase;
            if ($settings['button'] == true) {
                if ($settings['button_position'] == 'top') {
                    $output = $button . $showcase;
                } else {
                    $output = $showcase . $button;
                }
            }

            echo wp_kses_post(do_shortcode($output));
        }


        protected function render()
        {
            $settings = $this->get_settings_for_display();


            if (is_admin()) {
                $this->render_admin($settings);
            } else {
                $this->render_frontend($settings);
            }
        }
    }
}
